@@ -329,7 +329,7 @@ class GeneratorXmlThreeDotThree(AbstractGeneratorXml):
                 raise Exception('Se debe especificar una descripción para poder timbrar y posteriormente crear una poliza.')
             cfdi_concepto.setAttribute('ValorUnitario', str(concepto.get('valor_unitario')))
             cfdi_concepto.setAttribute('Importe', str(concepto.get('importe')))
-            if self.tipo_comprobante != TRASLADO:
+            if self.complemento not in [COMPLEMENTO_CARTA_PORTE, COMPLEMENTO_DONATARIAS]:
                 #revisar en el manual si lleva impuestos este tipo de comprobante
                 cfdi_concepto.appendChild(self.get_impuestos_concepto(concepto))
             if concepto.get('informacion_aduanera'):
