@@ -25,14 +25,14 @@ class GeneratorXmlFourDotZero(AbstractGeneratorXml):
         self.reset_dom()
         dom = self.dom.childNodes[0]
         dom.setAttribute('xmlns:cfdi', 'http://www.sat.gob.mx/cfd/4')
-        if self.data.get('tipo') == INGRESO and self.data.get('subtipo') == ST_RECIBO_DONATIVO: #recibo donativo
+        if self.tipo_comprobante == INGRESO and self.data.get('subtipo') == ST_RECIBO_DONATIVO: #recibo donativo
             dom.setAttribute('xsi:schemaLocation',
                              'http://www.sat.gob.mx/cfd/4 ' +
                              'http://www.sat.gob.mx/sitio_internet/cfd/4/cfdv40.xsd ' +
                              'http://www.sat.gob.mx/donat ' +
                              'http://www.sat.gob.mx/sitio_internet/cfd/donat/donat11.xsd')
             dom.setAttribute('xmlns:donat', 'http://www.sat.gob.mx/donat')
-        elif self.data.get('tipo') == PAGO:
+        elif self.tipo_comprobante == PAGO:
             dom.setAttribute('xmlns:pago20', 'http://www.sat.gob.mx/Pagos20')
             dom.setAttribute('xsi:schemaLocation',
                              'http://www.sat.gob.mx/cfd/4 ' +
